@@ -39,7 +39,7 @@ public:
     KCMAkregatorAppearanceConfig(QWidget *parent, const QVariantList &args);
 
 private:
-    QWidget *m_widget;
+    QWidget *m_widget = nullptr;
     Akregator::Ui::SettingsAppearance m_ui;
 };
 
