@@ -97,13 +97,13 @@ d4_inline c4_ThreadLock::~c4_ThreadLock()
 
 d4_inline c4_ThreadLock::Hold::Hold()
 {
-    d4_dbgdef(int r =)pthread_mutex_lock(&gMutex);
+    d4_dbgdef(int r = ) pthread_mutex_lock(&gMutex);
     d4_assert(r == 0);
 }
 
 d4_inline c4_ThreadLock::Hold::~Hold()
 {
-    d4_dbgdef(int r =)pthread_mutex_unlock(&gMutex);
+    d4_dbgdef(int r = ) pthread_mutex_unlock(&gMutex);
     d4_assert(r == 0);
 }
 
@@ -113,13 +113,21 @@ d4_inline c4_ThreadLock::Hold::~Hold()
 
 //  All other implementations revert to the simple "thread-less" case.
 
-d4_inline c4_ThreadLock::c4_ThreadLock() {}
+d4_inline c4_ThreadLock::c4_ThreadLock()
+{
+}
 
-d4_inline c4_ThreadLock::~c4_ThreadLock() {}
+d4_inline c4_ThreadLock::~c4_ThreadLock()
+{
+}
 
-d4_inline c4_ThreadLock::Hold::Hold() {}
+d4_inline c4_ThreadLock::Hold::Hold()
+{
+}
 
-d4_inline c4_ThreadLock::Hold::~Hold() {}
+d4_inline c4_ThreadLock::Hold::~Hold()
+{
+}
 
 #endif
 
@@ -128,7 +136,7 @@ d4_inline c4_ThreadLock::Hold::~Hold() {}
 #if defined(q4_LOGPROPMODS) && q4_LOGPROPMODS
 
 static FILE *sPropModsFile = 0;
-static int sPropModsProp =  - 1;
+static int sPropModsProp = -1;
 
 FILE *f4_LogPropMods(FILE *fp_, int propId_)
 {
@@ -179,7 +187,7 @@ void f4_DoLogProp(const c4_Handler *hp_, int id_, const char *fmt_, int arg_)
  */
 
 /// Construct a view based on a sequence
-c4_View::c4_View(c4_Sequence *seq_): _seq(seq_)
+c4_View::c4_View(c4_Sequence *seq_) : _seq(seq_)
 {
     if (!_seq) {
         _seq = d4_new c4_HandlerSeq(0);
@@ -189,7 +197,7 @@ c4_View::c4_View(c4_Sequence *seq_): _seq(seq_)
 }
 
 /// Construct a view based on a custom viewer
-c4_View::c4_View(c4_CustomViewer *viewer_): _seq(0)
+c4_View::c4_View(c4_CustomViewer *viewer_) : _seq(0)
 {
     d4_assert(viewer_);
 
@@ -199,7 +207,7 @@ c4_View::c4_View(c4_CustomViewer *viewer_): _seq(0)
 }
 
 /// Construct a view based on an input stream
-c4_View::c4_View(c4_Stream *stream_): _seq(c4_Persist::Load(stream_))
+c4_View::c4_View(c4_Stream *stream_) : _seq(c4_Persist::Load(stream_))
 {
     if (_seq == 0) {
         _seq = d4_new c4_HandlerSeq(0);
@@ -209,7 +217,7 @@ c4_View::c4_View(c4_Stream *stream_): _seq(c4_Persist::Load(stream_))
 }
 
 /// Construct an empty view with one property
-c4_View::c4_View(const c4_Property &prop_): _seq(d4_new c4_HandlerSeq(0))
+c4_View::c4_View(const c4_Property &prop_) : _seq(d4_new c4_HandlerSeq(0))
 {
     _IncSeqRef();
 
@@ -217,20 +225,20 @@ c4_View::c4_View(const c4_Property &prop_): _seq(d4_new c4_HandlerSeq(0))
 }
 
 /// Copy constructor
-c4_View::c4_View(const c4_View &view_): _seq(view_._seq)
+c4_View::c4_View(const c4_View &view_) : _seq(view_._seq)
 {
     _IncSeqRef();
 }
 
 /// Makes this view the same as another one.
-c4_View &c4_View::operator = (const c4_View &view_)
+c4_View &c4_View::operator =(const c4_View &view_)
 {
     if (_seq != view_._seq) {
         _DecSeqRef();
         _seq = view_._seq;
         _IncSeqRef();
     }
-    return  *this;
+    return *this;
 }
 
 /** Get a single data item in a generic way
@@ -239,14 +247,14 @@ c4_View &c4_View::operator = (const c4_View &view_)
  * Useful for c4_CustomViewers which are based on other views.
  * @return true if the item is non-empty
  */
-bool c4_View::GetItem(int row_, int col_, c4_Bytes &buf_)const
+bool c4_View::GetItem(int row_, int col_, c4_Bytes &buf_) const
 {
     const c4_Property &prop = NthProperty(col_);
     return prop(GetAt(row_)).GetData(buf_);
 }
 
 /// Set a single data item in a generic way
-void c4_View::SetItem(int row_, int col_, const c4_Bytes &buf_)const
+void c4_View::SetItem(int row_, int col_, const c4_Bytes &buf_) const
 {
     const c4_Property &prop = NthProperty(col_);
     prop(GetAt(row_)).SetData(buf_);
@@ -276,7 +284,7 @@ int c4_View::Add(const c4_RowRef &newElem_)
  *
  * The copy is a deep copy, because subviews are always copied in full.
  */
-c4_View c4_View::Duplicate()const
+c4_View c4_View::Duplicate() const
 {
     // insert all rows, sharing any subviews as needed
     c4_View result = Clone();
@@ -289,7 +297,7 @@ c4_View c4_View::Duplicate()const
  * Structural information can only be maintain for the top level,
  * subviews will be included but without any properties themselves.
  */
-c4_View c4_View::Clone()const
+c4_View c4_View::Clone() const
 {
     c4_View view;
 
@@ -313,7 +321,7 @@ int c4_View::AddProperty(const c4_Property &prop_)
  */
 const c4_Property &c4_View::NthProperty(int index_
                                         ///< the zero-based property index
-                                       )const
+                                        ) const
 {
     return _seq->NthHandler(index_).Property();
 }
@@ -324,7 +332,7 @@ const c4_Property &c4_View::NthProperty(int index_
  */
 int c4_View::FindPropIndexByName(const char *name_
                                  ///< property name (case insensitive)
-                                )const
+                                 ) const
 {
     // use a slow linear scan to find the untyped property by name
     for (int i = 0; i < NumProperties(); ++i) {
@@ -334,7 +342,7 @@ int c4_View::FindPropIndexByName(const char *name_
         }
     }
 
-    return  - 1;
+    return -1;
 }
 
 /** Defines a column for a property.
@@ -347,7 +355,7 @@ int c4_View::FindPropIndexByName(const char *name_
  * @return the new view object (without any data rows)
  * @sa c4_Property
  */
-c4_View c4_View::operator, (const c4_Property &prop_)const
+c4_View c4_View::operator,(const c4_Property &prop_) const
 {
     c4_View view = Clone();
     view.AddProperty(prop_);
@@ -369,7 +377,7 @@ void c4_View::InsertAt(int index_, const c4_View &view_)
     }
 }
 
-bool c4_View::IsCompatibleWith(const c4_View &dest_)const
+bool c4_View::IsCompatibleWith(const c4_View &dest_) const
 {
     // can't determine table without handlers (and can't be a table)
     if (NumProperties() == 0 || dest_.NumProperties() == 0) {
@@ -388,7 +396,7 @@ bool c4_View::IsCompatibleWith(const c4_View &dest_)const
 
     // both must not contain any temporary handlers
     if (s1->NumHandlers() != h1->NumFields() || s2->NumHandlers() != h2
-            ->NumFields()) {
+        ->NumFields()) {
         return false;
     }
 
@@ -439,9 +447,10 @@ void c4_View::RelocateRows(int from_, int count_, c4_View &dest_, int pos_)
             from_ += count_;
         }
 
-        for (int i = 0; i < count_; ++i)
+        for (int i = 0; i < count_; ++i) {
             ((c4_HandlerSeq *)_seq)->ExchangeEntries(from_ + i, *(c4_HandlerSeq *)
-                    dest_._seq, pos_ + i);
+                                                     dest_._seq, pos_ + i);
+        }
 
         RemoveAt(from_, count_);
     }
@@ -455,7 +464,7 @@ void c4_View::RelocateRows(int from_, int count_, c4_View &dest_, int pos_)
  * limitations with this scheme - one of them being that deriving another
  * view from this sorted one will not properly track changes.
  */
-c4_View c4_View::Sort()const
+c4_View c4_View::Sort() const
 {
     return f4_CreateSort(*_seq);
 }
@@ -468,9 +477,9 @@ c4_View c4_View::Sort()const
  * limitations with this scheme - one of them being that deriving another
  * view from this sorted one will not properly track changes.
  */
-c4_View c4_View::SortOn(const c4_View &up_)const
+c4_View c4_View::SortOn(const c4_View &up_) const
 {
-    c4_Sequence *seq = f4_CreateProject(*_seq,  *up_._seq, true);
+    c4_Sequence *seq = f4_CreateProject(*_seq, *up_._seq, true);
 
     return f4_CreateSort(*seq);
 }
@@ -486,9 +495,9 @@ c4_View c4_View::SortOn(const c4_View &up_)const
 c4_View c4_View::SortOnReverse(const c4_View &up_,
                                ///< the view which defines the sort order
                                const c4_View &down_  ///< subset of up_, defines reverse order
-                              )const
+                               ) const
 {
-    c4_Sequence *seq = f4_CreateProject(*_seq,  *up_._seq, true);
+    c4_Sequence *seq = f4_CreateProject(*_seq, *up_._seq, true);
 
     return f4_CreateSort(*seq, down_._seq);
 }
@@ -501,7 +510,7 @@ c4_View c4_View::SortOnReverse(const c4_View &up_,
  * which properly generate change notifications (.e. raw views, other
  * selections, and projections).
  */
-c4_View c4_View::Select(const c4_RowRef &crit_)const
+c4_View c4_View::Select(const c4_RowRef &crit_) const
 {
     return f4_CreateFilter(*_seq, &crit_, &crit_);
 }
@@ -517,7 +526,7 @@ c4_View c4_View::Select(const c4_RowRef &crit_)const
 c4_View c4_View::SelectRange(const c4_RowRef &low_,
                              ///< values of the lower bounds (inclusive)
                              const c4_RowRef &high_  ///< values of the upper bounds (inclusive)
-                            )const
+                             ) const
 {
     return f4_CreateFilter(*_seq, &low_, &high_);
 }
@@ -530,9 +539,9 @@ c4_View c4_View::SelectRange(const c4_RowRef &low_,
  * which properly generate change notifications (.e. raw views, selections,
  * and other projections).
  */
-c4_View c4_View::Project(const c4_View &in_)const
+c4_View c4_View::Project(const c4_View &in_) const
 {
-    return f4_CreateProject(*_seq,  *in_._seq, false);
+    return f4_CreateProject(*_seq, *in_._seq, false);
 }
 
 /** Create derived view with some properties omitted
@@ -543,9 +552,9 @@ c4_View c4_View::Project(const c4_View &in_)const
  * which properly generate change notifications (.e. raw views, selections,
  * and other projections).
  */
-c4_View c4_View::ProjectWithout(const c4_View &out_)const
+c4_View c4_View::ProjectWithout(const c4_View &out_) const
 {
-    return f4_CreateProject(*_seq,  *_seq, false, out_._seq);
+    return f4_CreateProject(*_seq, *_seq, false, out_._seq);
 }
 
 /** Create view which is a segment/slice (default is up to end)
@@ -557,7 +566,7 @@ c4_View c4_View::ProjectWithout(const c4_View &out_)const
  *
  * This view operation is based on a custom viewer and is modifiable.
  */
-c4_View c4_View::Slice(int first_, int limit_, int step_)const
+c4_View c4_View::Slice(int first_, int limit_, int step_) const
 {
     return f4_CustSlice(*_seq, first_, limit_, step_);
 }
@@ -571,7 +580,7 @@ c4_View c4_View::Slice(int first_, int limit_, int step_)const
  *
  * This view operation is based on a read-only custom viewer.
  */
-c4_View c4_View::Product(const c4_View &view_)const
+c4_View c4_View::Product(const c4_View &view_) const
 {
     return f4_CustProduct(*_seq, view_);
 }
@@ -586,7 +595,7 @@ c4_View c4_View::Product(const c4_View &view_)const
  *
  * This view operation is based on a custom viewer and is modifiable.
  */
-c4_View c4_View::RemapWith(const c4_View &view_)const
+c4_View c4_View::RemapWith(const c4_View &view_) const
 {
     return f4_CustRemapWith(*_seq, view_);
 }
@@ -599,7 +608,7 @@ c4_View c4_View::RemapWith(const c4_View &view_)const
  *
  * This view operation is based on a custom viewer and is modifiable.
  */
-c4_View c4_View::Pair(const c4_View &view_)const
+c4_View c4_View::Pair(const c4_View &view_) const
 {
     return f4_CustPair(*_seq, view_);
 }
@@ -614,7 +623,7 @@ c4_View c4_View::Pair(const c4_View &view_)const
  *
  * This view operation is based on a custom viewer and is modifiable.
  */
-c4_View c4_View::Concat(const c4_View &view_)const
+c4_View c4_View::Concat(const c4_View &view_) const
 {
     return f4_CustConcat(*_seq, view_);
 }
@@ -623,7 +632,7 @@ c4_View c4_View::Concat(const c4_View &view_)const
  *
  * This view operation is based on a custom viewer and is modifiable.
  */
-c4_View c4_View::Rename(const c4_Property &old_, const c4_Property &new_)const
+c4_View c4_View::Rename(const c4_Property &old_, const c4_Property &new_) const
 {
     return f4_CustRename(*_seq, old_, new_);
 }
@@ -643,7 +652,7 @@ c4_View c4_View::Rename(const c4_Property &old_, const c4_Property &new_)const
 c4_View c4_View::GroupBy(const c4_View &keys_,
                          ///< properties in this view determine grouping
                          const c4_ViewProp &result_  ///< name of new subview defined in result
-                        )const
+                         ) const
 {
     return f4_CustGroupBy(*_seq, keys_, result_);
 }
@@ -658,7 +667,7 @@ c4_View c4_View::GroupBy(const c4_View &keys_,
 c4_View c4_View::Counts(const c4_View &keys_,
                         ///< properties in this view determine grouping
                         const c4_IntProp &result_  ///< new count property defined in result
-                       )const
+                        ) const
 {
     return f4_CustGroupBy(*_seq, keys_, result_); // third arg is c4_IntProp
 }
@@ -667,7 +676,7 @@ c4_View c4_View::Counts(const c4_View &keys_,
  *
  * This view operation is based on a read-only custom viewer.
  */
-c4_View c4_View::Unique()const
+c4_View c4_View::Unique() const
 {
     c4_IntProp count("#N#");
     return Counts(Clone(), count).ProjectWithout(count);
@@ -680,7 +689,7 @@ c4_View c4_View::Unique()const
  *
  * This view operation is based on a read-only custom viewer.
  */
-c4_View c4_View::Union(const c4_View &view_)const
+c4_View c4_View::Union(const c4_View &view_) const
 {
     return Concat(view_).Unique();
 }
@@ -692,7 +701,7 @@ c4_View c4_View::Union(const c4_View &view_)const
  *
  * This view operation is based on a read-only custom viewer.
  */
-c4_View c4_View::Intersect(const c4_View &view_)const
+c4_View c4_View::Intersect(const c4_View &view_) const
 {
     c4_View v = Concat(view_);
 
@@ -708,7 +717,7 @@ c4_View c4_View::Intersect(const c4_View &view_)const
  *
  * This view operation is based on a read-only custom viewer.
  */
-c4_View c4_View::Different(const c4_View &view_)const
+c4_View c4_View::Different(const c4_View &view_) const
 {
     c4_View v = Concat(view_);
 
@@ -726,7 +735,7 @@ c4_View c4_View::Different(const c4_View &view_)const
  * This view operation is based on a read-only custom viewer.
  */
 c4_View c4_View::Minus(const c4_View &view_  ///< the second view
-                      )const
+                       ) const
 {
     // inefficient: calculate difference, then keep only those in self
     return Intersect(Different(view_));
@@ -743,7 +752,7 @@ c4_View c4_View::Minus(const c4_View &view_  ///< the second view
 c4_View c4_View::JoinProp(const c4_ViewProp &sub_,
                           ///< name of the subview to expand
                           bool outer_  ///< true: keep rows with empty subviews
-                         )const
+                          ) const
 {
     return f4_CustJoinProp(*_seq, sub_, outer_);
 }
@@ -756,7 +765,7 @@ c4_View c4_View::Join(const c4_View &keys_,
                       ///< properties in this view determine the join
                       const c4_View &view_,  ///< second view participating in the join
                       bool outer_  ///< true: keep rows with no match in second view
-                     )const
+                      ) const
 {
     // inefficient: calculate difference, then keep only those in self
     return f4_CustJoin(*_seq, keys_, view_, outer_);
@@ -766,7 +775,7 @@ c4_View c4_View::Join(const c4_View &keys_,
  *
  * This view operation is based on a custom viewer.
  */
-c4_View c4_View::ReadOnly()const
+c4_View c4_View::ReadOnly() const
 {
     return f4_CreateReadOnly(*_seq);
 }
@@ -797,7 +806,7 @@ c4_View c4_View::ReadOnly()const
  *  hash.Add(...)
  * @endcode
  */
-c4_View c4_View::Hash(const c4_View &map_, int numKeys_)const
+c4_View c4_View::Hash(const c4_View &map_, int numKeys_) const
 {
     return f4_CreateHash(*_seq, numKeys_, map_._seq);
 }
@@ -820,7 +829,7 @@ c4_View c4_View::Hash(const c4_View &map_, int numKeys_)const
  *
  * This view operation is based on a custom viewer and is modifiable.
  */
-c4_View c4_View::Blocked()const
+c4_View c4_View::Blocked() const
 {
     return f4_CreateBlocked(*_seq);
 }
@@ -841,7 +850,7 @@ c4_View c4_View::Blocked()const
  * This view can be combined with c4_View::Blocked, to create a 2-level
  * btree structure.
  */
-c4_View c4_View::Ordered(int numKeys_)const
+c4_View c4_View::Ordered(int numKeys_) const
 {
     return f4_CreateOrdered(*_seq, numKeys_);
 }
@@ -860,9 +869,9 @@ c4_View c4_View::Ordered(int numKeys_)const
  * deleted from the view.
  */
 c4_View c4_View::Indexed(const c4_View &map_, const c4_View &props_, bool
-                         unique_)const
+                         unique_) const
 {
-    return f4_CreateIndexed(*_seq,  *map_._seq, props_, unique_);
+    return f4_CreateIndexed(*_seq, *map_._seq, props_, unique_);
 }
 
 /** Return the index of the specified row in this view (or -1)
@@ -870,7 +879,7 @@ c4_View c4_View::Indexed(const c4_View &map_, const c4_View &props_, bool
  * This function can be used to "unmap" an index of a derived view back
  * to the original underlying view.
  */
-int c4_View::GetIndexOf(const c4_RowRef &row_)const
+int c4_View::GetIndexOf(const c4_RowRef &row_) const
 {
     c4_Cursor cursor = &row_;
 
@@ -893,7 +902,7 @@ int c4_View::RestrictSearch(const c4_RowRef &c_, int &pos_, int &count_)
  */
 int c4_View::Find(const c4_RowRef &crit_,  ///< the value to look for
                   int start_  ///< the index to start with
-                 )const
+                  ) const
 {
     d4_assert(start_ >= 0);
 
@@ -917,9 +926,8 @@ int c4_View::Find(const c4_RowRef &crit_,  ///< the value to look for
                     h.ClearBytes(data);
                 }
 
-                if (h.Compare(0, data) != 0)
+                if (h.Compare(0, data) != 0) {
                     // always row 0
-                {
                     break;
                 }
             }
@@ -930,21 +938,20 @@ int c4_View::Find(const c4_RowRef &crit_,  ///< the value to look for
         }
     }
 
-    return  - 1;
+    return -1;
 }
 
 /** Search for a key, using the native sort order of the view
  * @return position where found, or where it may be inserted,
  *  this position can also be just past the last row
  */
-int c4_View::Search(const c4_RowRef &crit_)const
+int c4_View::Search(const c4_RowRef &crit_) const
 {
-    int l =  - 1, u = GetSize();
+    int l = -1, u = GetSize();
     while (l + 1 != u) {
         const int m = (l + u) >> 1;
-        if (_seq->Compare(m, &crit_) < 0)
+        if (_seq->Compare(m, &crit_) < 0) {
             //if (crit_ > (*this)[m]) // Dec 2001: see comments below
-        {
             l = m;
         } else {
             u = m;
@@ -955,7 +962,7 @@ int c4_View::Search(const c4_RowRef &crit_)const
 }
 
 /// Return number of matching keys, and pos of first one as arg
-int c4_View::Locate(const c4_RowRef &crit_, int *pos_)const
+int c4_View::Locate(const c4_RowRef &crit_, int *pos_) const
 {
     // Dec 2001: fixed a problem with searching of partial rows.
     //
@@ -975,10 +982,10 @@ int c4_View::Locate(const c4_RowRef &crit_, int *pos_)const
 
     c4_Cursor curr(*(c4_Sequence *)_seq, 0); // loses const
 
-    int l =  - 1, u = GetSize();
+    int l = -1, u = GetSize();
     while (l + 1 != u) {
         curr._index = (l + u) >> 1;
-        if (crit_ >  *curr) {
+        if (crit_ > *curr) {
             l = curr._index;
         } else {
             u = curr._index;
@@ -991,15 +998,15 @@ int c4_View::Locate(const c4_RowRef &crit_, int *pos_)const
 
     // only look for more if the search hit an exact match
     curr._index = u;
-    if (u == GetSize() || crit_ !=  *curr) {
+    if (u == GetSize() || crit_ != *curr) {
         return 0;
     }
 
     // as Jon Bentley wrote in DDJ Apr 2000, setting l2 to -1 is better than u
-    int l2 =  - 1, u2 = GetSize();
+    int l2 = -1, u2 = GetSize();
     while (l2 + 1 != u2) {
         curr._index = (l2 + u2) >> 1;
-        if (crit_ >=  *curr) {
+        if (crit_ >= *curr) {
             l2 = curr._index;
         } else {
             u2 = curr._index;
@@ -1010,7 +1017,7 @@ int c4_View::Locate(const c4_RowRef &crit_, int *pos_)const
 }
 
 /// Compare two views lexicographically (rows 0..N-1).
-int c4_View::Compare(const c4_View &view_)const
+int c4_View::Compare(const c4_View &view_) const
 {
     if (_seq == view_._seq) {
         return 0;
@@ -1020,12 +1027,13 @@ int c4_View::Compare(const c4_View &view_)const
     int nb = view_.GetSize();
     int i;
 
-    for (i = 0; i < na && i < nb; ++i)
+    for (i = 0; i < na && i < nb; ++i) {
         if (GetAt(i) != view_.GetAt(i)) {
-            return GetAt(i) < view_.GetAt(i) ?  - 1 :  + 1;
+            return GetAt(i) < view_.GetAt(i) ? -1 : +1;
         }
+    }
 
-    return na == nb ? 0 : i < na ?  + 1 :  - 1;
+    return na == nb ? 0 : i < na ? +1 : -1;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -1069,16 +1077,18 @@ int c4_View::Compare(const c4_View &view_)const
 /////////////////////////////////////////////////////////////////////////////
 // c4_Row
 
-c4_Row::c4_Row(): c4_RowRef(*Allocate()) {}
-
-c4_Row::c4_Row(const c4_Row &row_): c4_RowRef(*Allocate())
+c4_Row::c4_Row() : c4_RowRef(*Allocate())
 {
-    operator = (row_);
 }
 
-c4_Row::c4_Row(const c4_RowRef &rowRef_): c4_RowRef(*Allocate())
+c4_Row::c4_Row(const c4_Row &row_) : c4_RowRef(*Allocate())
 {
-    operator = (rowRef_);
+    operator =(row_);
+}
+
+c4_Row::c4_Row(const c4_RowRef &rowRef_) : c4_RowRef(*Allocate())
+{
+    operator =(rowRef_);
 }
 
 c4_Row::~c4_Row()
@@ -1086,22 +1096,22 @@ c4_Row::~c4_Row()
     Release(_cursor);
 }
 
-c4_Row &c4_Row::operator = (const c4_Row &row_)
+c4_Row &c4_Row::operator =(const c4_Row &row_)
 {
-    return operator = ((const c4_RowRef &)row_);
+    return operator =((const c4_RowRef &)row_);
 }
 
 /// Assignment from a reference to a row.
-c4_Row &c4_Row::operator = (const c4_RowRef &rowRef_)
+c4_Row &c4_Row::operator =(const c4_RowRef &rowRef_)
 {
     d4_assert(_cursor._seq != 0);
 
-    if (_cursor !=  &rowRef_) {
+    if (_cursor != &rowRef_) {
         d4_assert(_cursor._index == 0);
         _cursor._seq->SetAt(0, &rowRef_);
     }
 
-    return  *this;
+    return *this;
 }
 
 /// Adds all properties and values into this row.
@@ -1112,7 +1122,7 @@ void c4_Row::ConcatRow(const c4_RowRef &rowRef_)
     c4_Cursor cursor = &rowRef_; // trick to access private rowRef_._cursor
     d4_assert(cursor._seq != 0);
 
-    c4_Sequence &rhSeq =  *cursor._seq;
+    c4_Sequence &rhSeq = *cursor._seq;
 
     c4_Bytes data;
 
@@ -1124,7 +1134,7 @@ void c4_Row::ConcatRow(const c4_RowRef &rowRef_)
     }
 }
 
-c4_Row operator + (const c4_RowRef &a_, const c4_RowRef &b_)
+c4_Row operator +(const c4_RowRef &a_, const c4_RowRef &b_)
 {
     c4_Row row = a_;
     row.ConcatRow(b_);
@@ -1183,7 +1193,7 @@ void c4_Property::CleanupInternalData()
     sThreadLock = 0; // race
 }
 
-c4_Property::c4_Property(char type_, const char *name_): _type(type_)
+c4_Property::c4_Property(char type_, const char *name_) : _type(type_)
 {
     if (sThreadLock == 0) {
         sThreadLock = d4_new c4_ThreadLock;
@@ -1213,10 +1223,11 @@ c4_Property::c4_Property(char type_, const char *name_): _type(type_)
     if (_id < 0) {
         int size = sPropCounts->GetSize();
 
-        for (_id = 0; _id < size; ++_id)
+        for (_id = 0; _id < size; ++_id) {
             if (sPropCounts->GetAt(_id) == 0) {
                 break;
             }
+        }
 
         if (_id >= size) {
             sPropCounts->SetSize(_id + 1);
@@ -1227,40 +1238,41 @@ c4_Property::c4_Property(char type_, const char *name_): _type(type_)
         sPropNames->SetAt(_id, name_);
     }
 
-    Refs(+ 1);
+    Refs(+1);
 }
 
-c4_Property::c4_Property(const c4_Property &prop_): _id(prop_.GetId()), _type
-    (prop_.Type())
+c4_Property::c4_Property(const c4_Property &prop_) : _id(prop_.GetId())
+    , _type
+        (prop_.Type())
 {
     c4_ThreadLock::Hold lock;
 
     d4_assert(sPropCounts != 0);
     d4_assert(sPropCounts->GetAt(_id) > 0);
 
-    Refs(+ 1);
+    Refs(+1);
 }
 
 c4_Property::~c4_Property()
 {
     c4_ThreadLock::Hold lock;
 
-    Refs(- 1);
+    Refs(-1);
 }
 
-void c4_Property::operator = (const c4_Property &prop_)
+void c4_Property::operator =(const c4_Property &prop_)
 {
     c4_ThreadLock::Hold lock;
 
-    prop_.Refs(+ 1);
-    Refs(- 1);
+    prop_.Refs(+1);
+    Refs(-1);
 
     _id = prop_.GetId();
     _type = prop_.Type();
 }
 
 /// Return the name of this property
-const char *c4_Property::Name()const
+const char *c4_Property::Name() const
 {
     c4_ThreadLock::Hold lock;
 
@@ -1273,9 +1285,9 @@ const char *c4_Property::Name()const
  *  This is part of the implementation and shouldn't normally be called.
  *  This code is only called with the lock held, and always thread-safe.
  */
-void c4_Property::Refs(int diff_)const
+void c4_Property::Refs(int diff_) const
 {
-    d4_assert(diff_ ==  - 1 || diff_ ==  + 1);
+    d4_assert(diff_ == -1 || diff_ == +1);
 
     d4_assert(sPropCounts != 0);
     sPropCounts->ElementAt(_id) += diff_;
