@@ -53,7 +53,6 @@
 #include <kxmlguifactory.h>
 #include <KGuiItem>
 
-#include <QApplication>
 #include <QHash>
 #include <QWidget>
 
@@ -104,27 +103,44 @@ public:
     }
 
 private:
-    ActionManagerImpl *m_manager;
+    ActionManagerImpl *m_manager = nullptr;
 };
 
 class ActionManagerImpl::ActionManagerImplPrivate
 {
 public:
     QString quickSearchLineText() const;
-    NodeSelectVisitor *nodeSelectVisitor;
-    ArticleListView *articleList;
-    SubscriptionListView *subscriptionListView;
-    MainWidget *mainWidget;
-    Part *part;
-    TrayIcon *trayIcon;
-    KActionMenu *tagMenu;
-    KActionCollection *actionCollection;
-    TabWidget *tabWidget;
-    PimCommon::ShareServiceUrlManager *shareServiceManager;
-    WebEngineViewer::ZoomActionMenu *zoomActionMenu;
-    QAction *mQuickSearchAction;
+    NodeSelectVisitor *nodeSelectVisitor = nullptr;
+    ArticleListView *articleList = nullptr;
+    SubscriptionListView *subscriptionListView = nullptr;
+    MainWidget *mainWidget = nullptr;
+    Part *part = nullptr;
+    TrayIcon *trayIcon = nullptr;
+    KActionMenu *tagMenu = nullptr;
+    KActionCollection *actionCollection = nullptr;
+    TabWidget *tabWidget = nullptr;
+    PimCommon::ShareServiceUrlManager *shareServiceManager = nullptr;
+    WebEngineViewer::ZoomActionMenu *zoomActionMenu = nullptr;
+    QAction *mQuickSearchAction = nullptr;
 };
 
+void ActionManagerImpl::slotSettingsChanged()
+{
+    QAction *a = action(QStringLiteral("feed_hide_read"));
+    if (!a) {
+        qCCritical(AKREGATOR_LOG) << "Action not found";
+        return;
+    }
+    a->setChecked(Settings::hideReadFeeds());
+
+    a = action(QStringLiteral("auto_expand_folders"));
+    if (!a) {
+        qCCritical(AKREGATOR_LOG) << "Action not found";
+        return;
+    }
+    a->setChecked(Settings::autoExpandFolders());
+}
+
 void ActionManagerImpl::slotNodeSelected(TreeNode *node)
 {
     if (node != 0) {
@@ -521,6 +537,18 @@ void ActionManagerImpl::initSubscriptionListView(SubscriptionListView *subscript
     action->setText(i18n("Go Down in Tree"));
     connect(action, &QAction::triggered, subscriptionListView, &SubscriptionListView::slotItemDown);
     coll->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_Down));
+
+    action = coll->addAction(QStringLiteral("feed_hide_read"));
+    action->setCheckable(true);
+    action->setText(i18n("Hide Read Feeds"));
+    action->setChecked(Settings::hideReadFeeds());
+    connect(action, &QAction::triggered, subscriptionListView, &SubscriptionListView::slotSetHideReadFeeds);
+
+    action = coll->addAction(QStringLiteral("auto_expand_folders"));
+    action->setCheckable(true);
+    action->setText(i18n("Auto-expand folders with unread articles"));
+    action->setChecked(Settings::autoExpandFolders());
+    connect(action, &QAction::triggered, subscriptionListView, &SubscriptionListView::slotSetAutoExpandFolders);
 }
 
 void ActionManagerImpl::initTabWidget(TabWidget *tabWidget)
