@@ -61,14 +61,12 @@ public Q_SLOTS:
     void fetchDiscovery(Akregator::Feed *);
     void fetchError(Akregator::Feed *);
 
-private Q_SLOTS:
-    void textChanged(const QString &);
-
 private:
+    void textChanged(const QString &);
     QString feedUrl;
-    AddFeedWidget *widget;
-    Feed *m_feed;
-    QPushButton *mOkButton;
+    AddFeedWidget *widget = nullptr;
+    Feed *m_feed = nullptr;
+    QPushButton *mOkButton = nullptr;
 };
 } // namespace Akregator
 
