@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -48,7 +48,7 @@ private:
     } mState;
 
     QString mHtml;
-    ArticleViewerWebEngine *mWebView;
+    ArticleViewerWebEngine *mWebView = nullptr;
 };
 }
 
