@@ -30,7 +30,6 @@
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineAccessKey>
 #include <KPIMTextEdit/TextToSpeech>
-#include <KActionMenu>
 
 #include <KParts/BrowserRun>
 #include <GrantleeTheme/GrantleeThemeManager>
@@ -39,19 +38,14 @@
 #include <KAboutData>
 #include <KGuiItem>
 #include <openurlrequest.h>
-#include <KPimPrintPreviewDialog>
 #include <KMessageBox>
 #include <QPrinter>
-#include <QWebEngineSettings>
 #include <QMouseEvent>
-#include <QPrintDialog>
 #include <QApplication>
 #include <QClipboard>
 #include <QMenu>
 #include <viewerplugintoolmanager.h>
 #include <QWebEngineProfile>
-#include <QWebEngineDownloadItem>
-#include <QPointer>
 
 #include <WebEngineViewer/WebHitTestResult>
 #include <WebEngineViewer/WebHitTest>
@@ -106,6 +100,11 @@ ArticleViewerWebEngine::~ArticleViewerWebEngine()
 {
 }
 
+void ArticleViewerWebEngine::execPrintPreviewPage(QPrinter *printer, int timeout)
+{
+    mPageEngine->execPrintPreviewPage(printer, timeout);
+}
+
 void ArticleViewerWebEngine::slotWebPageMutedOrAudibleChanged()
 {
     Q_EMIT webPageMutedOrAudibleChanged(page()->isAudioMuted(), page()->recentlyAudible());
@@ -123,7 +122,7 @@ QVariantHash ArticleViewerWebEngine::introductionData() const
 
 void ArticleViewerWebEngine::showAboutPage()
 {
-    paintAboutScreen(QStringLiteral("introduction_akregator.html"), introductionData());
+    paintAboutScreen(QStringLiteral(":/about/introduction_akregator.html"), introductionData());
 }
 
 void ArticleViewerWebEngine::paintAboutScreen(const QString &templateName, const QVariantHash &data)
