@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -70,11 +70,12 @@ public:
 
     void createViewerPluginToolManager(KActionCollection *ac, QWidget *parent);
 
+    void execPrintPreviewPage(QPrinter *printer, int timeout);
 protected:
     QUrl mCurrentUrl;
-    KActionCollection *mActionCollection;
-    PimCommon::ShareServiceUrlManager *mShareServiceManager;
-    KIO::KUriFilterSearchProviderActions *mWebShortcutMenuManager;
+    KActionCollection *mActionCollection = nullptr;
+    PimCommon::ShareServiceUrlManager *mShareServiceManager = nullptr;
+    KIO::KUriFilterSearchProviderActions *mWebShortcutMenuManager = nullptr;
 
 private:
     enum MousePressedButtonType {
@@ -128,15 +129,15 @@ private Q_SLOTS:
     void slotCheckedUrlFinished(const QUrl &url, WebEngineViewer::CheckPhishingUrlUtil::UrlStatus status);
 protected:
 
-    ArticleViewerWebEnginePage *mPageEngine;
+    ArticleViewerWebEnginePage *mPageEngine = nullptr;
     QList<QAction *> viewerPluginActionList(MessageViewer::ViewerPluginInterface::SpecificFeatureTypes features);
-    WebEngineViewer::InterceptorManager *mNetworkAccessManager;
+    WebEngineViewer::InterceptorManager *mNetworkAccessManager = nullptr;
 private:
     void openSafeUrl(const QUrl &url);
     bool urlIsAMalwareButContinue();
     MousePressedButtonType mLastButtonClicked;
-    MessageViewer::ViewerPluginToolManager *mViewerPluginToolManager;
-    WebEngineViewer::WebEngineAccessKey *mWebEngineViewAccessKey;
+    MessageViewer::ViewerPluginToolManager *mViewerPluginToolManager = nullptr;
+    WebEngineViewer::WebEngineAccessKey *mWebEngineViewAccessKey = nullptr;
 };
 }
 
