@@ -25,11 +25,7 @@ using namespace Akregator;
 ArticleViewerWebEnginePage::ArticleViewerWebEnginePage(QWebEngineProfile *profile, QObject *parent)
     : WebEngineViewer::WebEnginePage(profile, parent)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, false);
-#else
-    settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, true);
-#endif
     settings()->setAttribute(QWebEngineSettings::PluginsEnabled, false);
     settings()->setAttribute(QWebEngineSettings::AutoLoadImages, true);
     settings()->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, false);
@@ -40,20 +36,16 @@ ArticleViewerWebEnginePage::ArticleViewerWebEnginePage(QWebEngineProfile *profil
     settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessFileUrls, false);
     settings()->setAttribute(QWebEngineSettings::ErrorPageEnabled, false);
     settings()->setAttribute(QWebEngineSettings::HyperlinkAuditingEnabled, false);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     settings()->setAttribute(QWebEngineSettings::WebGLEnabled, false);
     settings()->setAttribute(QWebEngineSettings::AutoLoadIconsForPage, false);
     settings()->setAttribute(QWebEngineSettings::Accelerated2dCanvasEnabled, false);
     settings()->setAttribute(QWebEngineSettings::WebGLEnabled, false);
-#endif
     connect(this, &QWebEnginePage::featurePermissionRequested,
             this, &ArticleViewerWebEnginePage::slotFeaturePermissionRequested);
-
 }
 
 ArticleViewerWebEnginePage::~ArticleViewerWebEnginePage()
 {
-
 }
 
 bool ArticleViewerWebEnginePage::acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame)
