@@ -22,7 +22,6 @@
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <QVBoxLayout>
-#include <QAction>
 #include <viewerplugintoolmanager.h>
 #include <KRun>
 
@@ -30,15 +29,13 @@
 
 #include <kpimtextedit/slidecontainer.h>
 
-#include <WebEngineViewer/WebEnginePrintMessageBox>
 #include <WebEngineViewer/FindBarWebEngineView>
-#include <webengineviewer/config-webengineviewer.h>
 #include <WebEngineViewer/WebEngineExportHtmlPageJob>
 
+#include <QApplication>
 #include <QPrinter>
-#ifdef WEBENGINEVIEWER_PRINT_SUPPORT
 #include <QPrintDialog>
-#endif
+#include <QPrintPreviewDialog>
 
 using namespace Akregator;
 template<typename Arg, typename R, typename C>
@@ -133,17 +130,11 @@ void ArticleViewerWebEngineWidgetNg::saveCurrentPosition()
 
 void ArticleViewerWebEngineWidgetNg::slotPrint()
 {
-#ifdef WEBENGINEVIEWER_PRINT_SUPPORT
     printRequested(mArticleViewerNg->page());
-#else
-    //Use the same code for the moment.
-    slotPrintPreview();
-#endif
 }
 
 void ArticleViewerWebEngineWidgetNg::printRequested(QWebEnginePage *page)
 {
-#ifdef WEBENGINEVIEWER_PRINT_SUPPORT
     if (mCurrentPrinter) {
         return;
     }
@@ -157,9 +148,6 @@ void ArticleViewerWebEngineWidgetNg::printRequested(QWebEnginePage *page)
     }
     delete dialog;
     page->print(mCurrentPrinter, invoke(this, &ArticleViewerWebEngineWidgetNg::slotHandlePagePrinted));
-#else
-    Q_UNUSED(page);
-#endif
 }
 
 void ArticleViewerWebEngineWidgetNg::slotHandlePagePrinted(bool result)
@@ -171,10 +159,18 @@ void ArticleViewerWebEngineWidgetNg::slotHandlePagePrinted(bool result)
 
 void ArticleViewerWebEngineWidgetNg::slotPrintPreview()
 {
-    QPointer<WebEngineViewer::WebEnginePrintMessageBox> dialog = new WebEngineViewer::WebEnginePrintMessageBox(this);
-    connect(dialog.data(), &WebEngineViewer::WebEnginePrintMessageBox::openInBrowser, this, &ArticleViewerWebEngineWidgetNg::slotOpenInBrowser);
-    dialog->exec();
-    delete dialog;
+    QPrintPreviewDialog *dialog = new QPrintPreviewDialog(this);
+    dialog->setAttribute(Qt::WA_DeleteOnClose);
+    dialog->resize(800, 750);
+
+    connect(dialog, &QPrintPreviewDialog::paintRequested, this, [=](QPrinter *printing) {
+        QApplication::setOverrideCursor(Qt::WaitCursor);
+
+        mArticleViewerNg->execPrintPreviewPage(printing, 10*1000);
+        QApplication::restoreOverrideCursor();
+    });
+
+    dialog->open();
 }
 
 void ArticleViewerWebEngineWidgetNg::slotOpenInBrowser()
@@ -187,7 +183,9 @@ void ArticleViewerWebEngineWidgetNg::slotOpenInBrowser()
         connect(job, &WebEngineViewer::WebEngineExportHtmlPageJob::success, this, &ArticleViewerWebEngineWidgetNg::slotExportHtmlPageSuccess);
         job->start();
     } else {
-        KRun::runUrl(currentUrl, QStringLiteral("text/html"), this);
+        KRun::RunFlags flags;
+        flags |= KRun::RunExecutables;
+        KRun::runUrl(currentUrl, QStringLiteral("text/html"), this, flags);
     }
 }
 
@@ -199,5 +197,7 @@ void ArticleViewerWebEngineWidgetNg::slotExportHtmlPageFailed()
 void ArticleViewerWebEngineWidgetNg::slotExportHtmlPageSuccess(const QString &filename)
 {
     const QUrl url(QUrl::fromLocalFile(filename));
-    KRun::runUrl(url, QStringLiteral("text/html"), this, true);
+    KRun::RunFlags flags;
+    flags |= KRun::DeleteTemporaryFiles;
+    KRun::runUrl(url, QStringLiteral("text/html"), this, flags);
 }
