@@ -60,7 +60,7 @@ public:
 
     QString fileName;
     QDomDocument defaultFeedList;
-    Storage *storage;
+    Storage *storage = nullptr;
 };
 
 void LoadFeedListCommand::Private::emitResult(const QSharedPointer<FeedList> &list)
@@ -96,7 +96,7 @@ QString LoadFeedListCommand::Private::createBackup(const QString &path, bool *ok
 {
     const QString backup = path
                            + QLatin1String("-backup.")
-                           + QString::number(QDateTime::currentDateTimeUtc().toTime_t());
+                           + QString::number(QDateTime::currentDateTimeUtc().toSecsSinceEpoch());
 
     const bool copied = QFile::copy(path, backup);
     if (ok) {
@@ -132,7 +132,9 @@ void LoadFeedListCommand::setStorage(Backend::Storage *s)
 
 void LoadFeedListCommand::doStart()
 {
-    QTimer::singleShot(KRandom::random() % 400, this, SLOT(doLoad()));
+    QTimer::singleShot(KRandom::random() % 400, this, [this]() {
+        d->doLoad();
+    });
 }
 
 void LoadFeedListCommand::doAbort()
