@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,8 +21,7 @@
 #define CRASHWIDGET_H
 
 #include <QWidget>
-namespace Akregator
-{
+namespace Akregator {
 class CrashWidget : public QWidget
 {
     Q_OBJECT
