@@ -93,8 +93,9 @@ protected:
     void setLoadLinkedWebsite(bool enabled);
 
 private:
-    FeedPropertiesWidget *widget;
-    Feed *m_feed;
+    FeedPropertiesWidget *widget = nullptr;
+    Feed *m_feed = nullptr;
+    QPushButton *mOkButton = nullptr;
 
 private Q_SLOTS:
     void slotSetWindowTitle(const QString &);
