@@ -27,13 +27,8 @@
 #include "treenodevisitor.h"
 #include "utils.h"
 
-#include <KLocalizedString>
-
-#include <QApplication>
 #include <QPaintDevice>
-#include <QPalette>
 #include <QString>
-#include <KFormat>
 
 using namespace Syndication;
 
@@ -72,7 +67,7 @@ public:
 
     QString text;
 private:
-    DefaultNormalViewFormatter *parent;
+    DefaultNormalViewFormatter *parent = nullptr;
 };
 
 DefaultNormalViewFormatter::DefaultNormalViewFormatter(const QString &grantleeDirectory, const QUrl &imageDir, QPaintDevice *device)
