@@ -23,13 +23,11 @@
 */
 
 #include "framemanager.h"
-#include "config-akregator.h"
 #include "akregatorconfig.h"
 #include "frame.h"
 #include "actionmanager.h"
 #include "openurlrequest.h"
 #include <KRun>
-#include <QAction>
 #include <KMacroExpander>
 #include <kprocess.h>
 #include <kshell.h>
@@ -37,7 +35,6 @@
 #include "akregator_debug.h"
 #include <webengine/webengineframe.h>
 #include <QStringList>
-#include <QApplication>
 #include <QDesktopServices>
 
 using namespace Akregator;
