@@ -21,7 +21,7 @@
 #define MAINFRAME_H
 
 #include "frame.h"
-#include "config-akregator.h"
+
 namespace Akregator {
 class ArticleViewerWidget;
 class AKREGATOR_EXPORT MainFrame : public Frame
@@ -57,7 +57,7 @@ public Q_SLOTS:
     void slotSaveImageOnDiskInFrame(int frameId);
     void slotMute(int frameId, bool mute);
 private:
-    Akregator::ArticleViewerWidget *mArticleViewer;
+    Akregator::ArticleViewerWidget *mArticleViewer = nullptr;
 };
 } // namespace Akregator
 
