@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,8 +23,7 @@
 #include "articleviewer-ng/webengine/articleviewerwebengine.h"
 
 class KActionCollection;
-namespace Akregator
-{
+namespace Akregator {
 class AkrWebEngineViewer : public ArticleViewerWebEngine
 {
     Q_OBJECT
@@ -33,13 +32,12 @@ public:
     ~AkrWebEngineViewer();
 
 protected:
-    void displayContextMenu(const QPoint &pos) Q_DECL_OVERRIDE;
+    void displayContextMenu(const QPoint &pos) override;
 
-    void contextMenuEvent(QContextMenuEvent *e) Q_DECL_OVERRIDE;
-    QWebEngineView *createWindow(QWebEnginePage::WebWindowType type) Q_DECL_OVERRIDE;
+    void contextMenuEvent(QContextMenuEvent *e) override;
+    QWebEngineView *createWindow(QWebEnginePage::WebWindowType type) override;
 private Q_SLOTS:
     void slotWebHitFinished(const WebEngineViewer::WebHitTestResult &result);
-
 };
 }
 
