@@ -66,7 +66,6 @@
 #include <WebEngineViewer/ZoomActionMenu>
 #include "job/downloadarticlejob.h"
 
-#include <QAction>
 #include <kfileitem.h>
 #include <KLocalizedString>
 #include <kmessagebox.h>
@@ -79,7 +78,6 @@
 #include <QClipboard>
 #include <QNetworkConfigurationManager>
 #include <QSplitter>
-#include <QTextDocument>
 #include <QDomDocument>
 #include <QTimer>
 #include <QDesktopServices>
@@ -122,6 +120,9 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
     m_displayingAboutPage = false;
     setFocusPolicy(Qt::StrongFocus);
 
+    connect(m_part, &Part::signalSettingsChanged,
+            m_actionManager, &ActionManagerImpl::slotSettingsChanged);
+
     QVBoxLayout *lt = new QVBoxLayout(this);
     lt->setMargin(0);
 
@@ -214,6 +215,9 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
     connect(m_searchBar, &SearchBar::signalSearch,
             m_selectionController, &AbstractSelectionController::setFilters);
 
+    connect(m_part, &Part::signalSettingsChanged,
+            m_selectionController, &AbstractSelectionController::settingsChanged);
+
     FolderExpansionHandler *expansionHandler = new FolderExpansionHandler(this);
     connect(m_feedListView, &QTreeView::expanded, expansionHandler, &FolderExpansionHandler::itemExpanded);
     connect(m_feedListView, &QTreeView::collapsed, expansionHandler, &FolderExpansionHandler::itemCollapsed);
