@@ -72,9 +72,9 @@ private:
     int m_intervalsLapsed;
     int m_maxIntervals;
     int m_maxArticles;
-    bool m_running;
-    bool m_addedInLastInterval;
-    QWidget *m_widget;
+    bool m_running = false;
+    bool m_addedInLastInterval = false;
+    QWidget *m_widget = nullptr;
     QString m_componantName;
 
     QVector<Article> m_articles;
