@@ -26,10 +26,12 @@
 #include "subscriptionlistmodel.h"
 #include "subscriptionlistdelegate.h"
 #include "akregatorconfig.h"
+#include "akregator_debug.h"
 
 #include <QHeaderView>
 #include <QStack>
 #include <QPointer>
+#include <QQueue>
 
 #include <QMenu>
 #include <KLocalizedString>
@@ -387,6 +389,60 @@ void SubscriptionListView::slotItemDown()
     setCurrentIndex(current.sibling(current.row() + 1, current.column()));
 }
 
+void SubscriptionListView::slotSetHideReadFeeds(bool setting)
+{
+    QAbstractItemModel *m = model();
+    if (!m) {
+        return;
+    }
+
+    FilterUnreadProxyModel *filter = qobject_cast<FilterUnreadProxyModel *>(m);
+    if (!filter) {
+        qCCritical(AKREGATOR_LOG) << "Unable to cast model to FilterUnreadProxyModel*";
+        return;
+    }
+
+    Settings::setHideReadFeeds(setting);
+    filter->setDoFilter(setting);
+}
+
+void Akregator::SubscriptionListView::slotSetAutoExpandFolders(bool setting)
+{
+    Settings::setAutoExpandFolders(setting);
+    if (!setting) {
+        return;
+    }
+
+    //expand any current subscriptions with unread items
+    QQueue<QModelIndex> indexes;
+    //start at the root node
+    indexes.enqueue(QModelIndex());
+
+    QAbstractItemModel *m = model();
+    if (!m) {
+        return;
+    }
+
+    while (!indexes.isEmpty()) {
+        QModelIndex parent = indexes.dequeue();
+        int rows = m->rowCount(parent);
+
+        for (int row = 0; row < rows; ++row) {
+            QModelIndex current = m->index(row, 0, parent);
+
+            if (m->hasChildren(current)) {
+                indexes.enqueue(current);
+            }
+
+            if (!m->data(current, SubscriptionListModel::HasUnreadRole).toBool()) {
+                continue;
+            }
+
+            setExpanded(current, true);
+        }
+    }
+}
+
 void Akregator::SubscriptionListView::ensureNodeVisible(Akregator::TreeNode *)
 {
 }
