@@ -72,6 +72,9 @@ public Q_SLOTS:
     void slotItemUp();
     void slotItemDown();
 
+    void slotSetHideReadFeeds(bool setting);
+    void slotSetAutoExpandFolders(bool setting);
+
 Q_SIGNALS:
     void userActionTakingPlace();
 
@@ -80,11 +83,10 @@ private:
     void loadHeaderSettings();
     void restoreHeaderState();
 
-private Q_SLOTS:
+private:
     void showHeaderMenu(const QPoint &pos);
     void headerMenuItemTriggered(QAction *action);
 
-private:
     QByteArray m_headerState;
 };
 }
