@@ -29,9 +29,7 @@
 
 class QString;
 
-namespace Akregator
-{
-
+namespace Akregator {
 class Frame;
 class OpenUrlRequest;
 
@@ -87,8 +85,8 @@ Q_SIGNALS:
     void signalSaveImageOnDisk(int currentFrame);
     void signalMute(int currentFrame, bool);
 private:
-    void tabInserted(int) Q_DECL_OVERRIDE;
-    void tabRemoved(int) Q_DECL_OVERRIDE;
+    void tabInserted(int) override;
+    void tabRemoved(int) override;
 
 private Q_SLOTS:
     void slotCloseRequest(int index);
@@ -101,7 +99,6 @@ private:
     class Private;
     Private *const d;
 };
-
 } // namespace Akregator
 
 #endif // AKREGATOR_TABWIDGET_H
