@@ -27,16 +27,12 @@
 
 #include "akregator_debug.h"
 #include <KLocalizedString>
-#include <QMenu>
 #include <kiconloader.h>
 #include <KColorScheme>
 
-#include <QPainter>
-#include <QFontDatabase>
-
 using namespace Akregator;
 
-TrayIcon *TrayIcon::m_instance = 0;
+TrayIcon *TrayIcon::m_instance = nullptr;
 
 TrayIcon *TrayIcon::getInstance()
 {
