@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,13 +23,15 @@
 #include <QUrl>
 #include <QString>
 #include <QPoint>
-namespace Akregator
-{
+namespace Akregator {
 class ArticleViewerWebEngine;
 class URLHandlerWebEngine
 {
 public:
-    virtual ~URLHandlerWebEngine() {}
+    virtual ~URLHandlerWebEngine()
+    {
+    }
+
     /**
       * Called when LMB-clicking on a link in the reader. Should start
       * processing equivalent to "opening" the link.
@@ -62,35 +64,50 @@ class AkregatorConfigHandler : public URLHandlerWebEngine
 {
 public:
     AkregatorConfigHandler()
-        : URLHandlerWebEngine() {}
-    virtual ~AkregatorConfigHandler() {}
-    bool handleClick(const QUrl &, ArticleViewerWebEngine *) const Q_DECL_OVERRIDE;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ArticleViewerWebEngine *) const Q_DECL_OVERRIDE;
-    QString statusBarMessage(const QUrl &, ArticleViewerWebEngine *) const Q_DECL_OVERRIDE;
+        : URLHandlerWebEngine()
+    {
+    }
+
+    virtual ~AkregatorConfigHandler()
+    {
+    }
+
+    bool handleClick(const QUrl &, ArticleViewerWebEngine *) const override;
+    bool handleContextMenuRequest(const QUrl &, const QPoint &, ArticleViewerWebEngine *) const override;
+    QString statusBarMessage(const QUrl &, ArticleViewerWebEngine *) const override;
 };
 
 class MailToURLHandlerWebEngine : public URLHandlerWebEngine
 {
 public:
-    MailToURLHandlerWebEngine() : URLHandlerWebEngine() {}
-    virtual ~MailToURLHandlerWebEngine() {}
+    MailToURLHandlerWebEngine() : URLHandlerWebEngine()
+    {
+    }
 
-    bool handleClick(const QUrl &, ArticleViewerWebEngine *) const Q_DECL_OVERRIDE;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ArticleViewerWebEngine *) const Q_DECL_OVERRIDE;
-    QString statusBarMessage(const QUrl &, ArticleViewerWebEngine *) const Q_DECL_OVERRIDE;
+    virtual ~MailToURLHandlerWebEngine()
+    {
+    }
+
+    bool handleClick(const QUrl &, ArticleViewerWebEngine *) const override;
+    bool handleContextMenuRequest(const QUrl &, const QPoint &, ArticleViewerWebEngine *) const override;
+    QString statusBarMessage(const QUrl &, ArticleViewerWebEngine *) const override;
 };
 
 class ActionURLHandlerWebEngine : public URLHandlerWebEngine
 {
 public:
-    ActionURLHandlerWebEngine() : URLHandlerWebEngine() {}
-    virtual ~ActionURLHandlerWebEngine() {}
+    ActionURLHandlerWebEngine() : URLHandlerWebEngine()
+    {
+    }
 
-    bool handleClick(const QUrl &, ArticleViewerWebEngine *) const Q_DECL_OVERRIDE;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ArticleViewerWebEngine *) const Q_DECL_OVERRIDE;
-    QString statusBarMessage(const QUrl &, ArticleViewerWebEngine *) const Q_DECL_OVERRIDE;
+    virtual ~ActionURLHandlerWebEngine()
+    {
+    }
+
+    bool handleClick(const QUrl &, ArticleViewerWebEngine *) const override;
+    bool handleContextMenuRequest(const QUrl &, const QPoint &, ArticleViewerWebEngine *) const override;
+    QString statusBarMessage(const QUrl &, ArticleViewerWebEngine *) const override;
 };
-
 }
 
 #endif // URLHANDLERWebEngine_H
