@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -24,8 +24,7 @@
 #include <QVector>
 #include "akregator_export.h"
 
-namespace Akregator
-{
+namespace Akregator {
 class URLHandlerWebEngine;
 class ArticleViewerWebEngine;
 class AKREGATOR_EXPORT URLHandlerWebEngineManager : public QObject
