@@ -32,10 +32,6 @@
 #include <klineedit.h>
 #include <KLocalizedString>
 
-#include <QIcon>
-
-#include <QLabel>
-#include <QList>
 #include <QString>
 #include <QTimer>
 #include <QStandardPaths>
@@ -48,7 +44,7 @@ class SearchBar::SearchBarPrivate
 public:
     QString searchText;
     QTimer timer;
-    StatusSearchLine *searchLine;
+    StatusSearchLine *searchLine = nullptr;
     int delay;
     std::vector<QSharedPointer<const AbstractMatcher> > matchers;
     void triggerTimer()
@@ -87,7 +83,7 @@ SearchBar::SearchBar(QWidget *parent)
 SearchBar::~SearchBar()
 {
     delete d;
-    d = 0;
+    d = nullptr;
 }
 
 QString SearchBar::text() const
